Index: trunk/psphot/src/psphotFullFit.c
===================================================================
--- trunk/psphot/src/psphotFullFit.c	(revision 5828)
+++ trunk/psphot/src/psphotFullFit.c	(revision 5993)
@@ -14,15 +14,15 @@
     sources = psArraySort (sources, psphotSortBySN);
     
-    // galaxy model parameters
-    float GAL_MIN_SN  	   = psMetadataLookupF32 (&status, config, "GAL_MIN_SN");
-    float GAL_MOMENTS_RAD  = psMetadataLookupF32 (&status, config, "GAL_MOMENTS_RADIUS");
+    // extended source model parameters
+    float EXT_MIN_SN  	   = psMetadataLookupF32 (&status, config, "EXT_MIN_SN");
+    float EXT_MOMENTS_RAD  = psMetadataLookupF32 (&status, config, "EXT_MOMENTS_RADIUS");
 
-    // 'galaxy' model descriptions
-    char         *modelNameFLT = psMetadataLookupPtr (&status, config, "GAL_MODEL");
-    pmModelType   modelTypeFLT = pmModelSetType (modelNameFLT);
+    // extended source model descriptions
+    char         *modelNameEXT = psMetadataLookupPtr (&status, config, "EXT_MODEL");
+    pmModelType   modelTypeEXT = pmModelSetType (modelNameEXT);
 
     psphotInitLimitsPSF (config);
     psphotInitRadiusPSF (config, sky, psf->type);
-    psphotInitRadiusFLT (config, sky, modelTypeFLT);
+    psphotInitRadiusEXT (config, sky, modelTypeEXT);
 
     for (int i = 0; i < sources->n; i++) {
@@ -82,34 +82,34 @@
 
 	// skip the source if we don't think it is extended
-	if (source->type != PM_SOURCE_GALAXY) goto subLINEAR;
-	if (source->moments->SN < GAL_MIN_SN) goto subLINEAR;
+	if (source->type != PM_SOURCE_EXTENDED) goto subLINEAR;
+	if (source->moments->SN < EXT_MIN_SN) goto subLINEAR;
 
 	// add the double-PSF fit mode
 	// how do we compare the results?  chisq? 
 	
-	// recalculate the source moments using the larger galaxy moments radius
-	if (!pmSourceMoments (source, GAL_MOMENTS_RAD)) goto subLINEAR;
+	// recalculate the source moments using the larger extended-source moments radius
+	if (!pmSourceMoments (source, EXT_MOMENTS_RAD)) goto subLINEAR;
 
 	// use the source moments, etc to guess basic model parameters
-	source->modelFLT = pmSourceModelGuess (source, modelTypeFLT); 
-	pmModel *modelFLT = source->modelFLT;
+	source->modelEXT = pmSourceModelGuess (source, modelTypeEXT); 
+	pmModel *modelEXT = source->modelEXT;
 
-	psphotCheckRadiusFLT (imdata, source, modelFLT);
+	psphotCheckRadiusEXT (imdata, source, modelEXT);
 
-	x = modelFLT->params->data.F32[2];
-	y = modelFLT->params->data.F32[3];
+	x = modelEXT->params->data.F32[2];
+	y = modelEXT->params->data.F32[3];
 
-	// fit FLT (not PSF) model (set/unset the pixel mask)
-	psImageKeepCircle (source->mask, x, y, modelFLT->radius, "OR", PSPHOT_MASK_MARKED);
-	pmSourceFitModel (source, modelFLT, false);
-	psImageKeepCircle (source->mask, x, y, modelFLT->radius, "AND", ~PSPHOT_MASK_MARKED);
+	// fit EXT (not PSF) model (set/unset the pixel mask)
+	psImageKeepCircle (source->mask, x, y, modelEXT->radius, "OR", PSPHOT_MASK_MARKED);
+	pmSourceFitModel (source, modelEXT, false);
+	psImageKeepCircle (source->mask, x, y, modelEXT->radius, "AND", ~PSPHOT_MASK_MARKED);
 
 	// track model evaluations
-	Niter += modelFLT[0].nIter;
+	Niter += modelEXT[0].nIter;
 	Nfit++;
 
-	// does the FLT model succeed?
-	if (psphotEvalFLT (source, source->modelFLT)) {
-	    pmSourceSubModel (source->pixels, source->mask, source->modelFLT, false, false);
+	// does the EXT model succeed?
+	if (psphotEvalEXT (source, source->modelEXT)) {
+	    pmSourceSubModel (source->pixels, source->mask, source->modelEXT, false, false);
 	    source->mode |=  PM_SOURCE_SUBTRACTED;
 	    source->mode &= ~PM_SOURCE_TEMPSUB;
